// Load the iris dataset from a URL
const url = "https://gist.githubusercontent.com/Bhanuteja-1807/9e7f866e0b4446e10eebe06191eda2ac/raw/2bb92cb24fe95cb641afff16003fb68aa20cfa73/Iris.csv";
d3.csv(url, function(error, data) {
  if (error) throw error;
  
  // Define the dimensions of the chart
  const width = 600;
  const height = 400;
  const padding = 50;

  // Create the SVG element
  const svg = d3.select("body")
    .append("svg")
    .attr("width", width)
    .attr("height", height);

  // Define the scales
  const xScale = d3.scaleLinear()
    .domain([d3.min(data, d => d.SepalLengthcm), d3.max(data, d => d.SepalLengthcm)])
    .range([padding, width - padding]);
  const yScale = d3.scaleLinear()
    .domain([d3.min(data, d => d.SepalWidthcm), d3.max(data, d => d.SepalWidthcm)])
    .range([height - padding, padding]);

  // Add the x-axis
  const xAxis = d3.axisBottom(xScale);
  svg.append("g")
    .attr("transform", "translate(0," + (height - padding) + ")")
    .call(xAxis);

  // Add the y-axis
  const yAxis = d3.axisLeft(yScale);
  svg.append("g")
    .attr("transform", "translate(" + padding + ",0)")
    .call(yAxis);

  // Add the data points
  svg.selectAll("circle")
    .data(data)
    .enter()
    .append("circle")
    .attr("cx", d => xScale(d.SepalLengthcm))
    .attr("cy", d => yScale(d.SepalWidthcm))
    .attr("r", 5)
    .attr("fill", d => {
      if (d.species === "Iris-setosa") {
        return "red";
      } else if (d.species === "Iris-versicolor") {
        return "green";
      } else {
        return "blue";
      }
    });
});
